Interval

Struct Interval 

pub struct Interval { /* private fields */ }
A stream representing notifications at fixed interval

Intervals are created through the Interval::new or Interval::new_at methods indicating when a first notification should be triggered and when it will be repeated.

Note that intervals are not intended for high resolution timers, but rather they will likely fire some granularity after the exact instant that they’re otherwise indicated to fire at.

Implementations

Source

impl Interval

pub async fn tick(&mut self) -> Instant

pub fn poll_tick(&mut self, cx: &mut Context<'_>) -> Poll<Instant>

pub fn reset(&mut self)

pub fn missed_tick_behavior(&self) -> MissedTickBehavior

Returns the MissedTickBehavior strategy currently being used.

pub fn set_missed_tick_behavior(&mut self, behavior: MissedTickBehavior)

Sets the MissedTickBehavior strategy that should be used.

pub fn period(&self) -> Duration

Returns the period of the interval.